@@ -48,7 +48,7 @@ void exit_event_handler (gboolean die_now, gpointer data);
 static gchar *_app_file_chooser (Application *app, GtkFileChooserAction act) {
     GtkWidget *dialog;
     gchar *filename = NULL;
-    dialog = hildon_file_chooser_dialog_new (GTK_WINDOW (app->window), act);
+    dialog = hildon_file_chooser_dialog_new (app->window, act);
     gtk_widget_show_all (GTK_WIDGET (dialog));
     if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
         filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
@@ -58,7 +58,7 @@ static gchar *_app_file_chooser (Application *app, GtkFileChooserAction act) {
 }
 
 void app_set_title (const char *title, Application *app) {
-    gtk_window_set_title (GTK_WINDOW (app->window), title);
+    gtk_window_set_title (app->window, title);
 }
 
 void app_insert_location (Application *app, const char *loc) {
@@ -95,7 +95,7 @@ void app_insert_location (Application *app, const char *loc) {
 }
 
 void app_open_location (const char *filename, Application *app) {
-    gtk_window_set_title (GTK_WINDOW (app->window), filename);
+    gtk_window_set_title (app->window, filename);
     openFile (app, filename);
     app_insert_location (app, filename);
 }
@@ -123,6 +123,50 @@ void app_set_playing (Application *app, bool p) {
     }
 }
 
+static void _app_setup_window (GtkWidget * w, Application *app) {
+    gtk_widget_add_events (w,
+            GDK_EXPOSURE_MASK | GDK_VISIBILITY_NOTIFY_MASK |
+            GDK_BUTTON_PRESS_MASK | GDK_KEY_PRESS_MASK |
+            GDK_STRUCTURE_MASK);
+    g_signal_connect (G_OBJECT (w), "realize",
+        GTK_SIGNAL_FUNC (cb_view_area_realized), app);
+    g_signal_connect (G_OBJECT (w), "expose-event",
+        GTK_SIGNAL_FUNC (cb_view_area_expose), app);
+    g_signal_connect (G_OBJECT (w), "button-press-event",
+        GTK_SIGNAL_FUNC (cb_view_area_button_press), app);
+    g_signal_connect (G_OBJECT (w), "configure-event",
+            GTK_SIGNAL_FUNC (cb_view_area_configure), app);
+}
+
+void app_full_screen (Application *app) {
+    if (!app->fullscreen) {
+        if (!app->window_fullscreen) {
+            HildonWindow *win = HILDON_WINDOW (hildon_window_new ());
+            app->window_fullscreen = GTK_WINDOW (win);
+            app->view_area_fullscreen = gtk_drawing_area_new ();
+            gtk_container_add (GTK_CONTAINER (win),
+                    app->view_area_fullscreen);
+            _app_setup_window (app->view_area_fullscreen, app);
+            hildon_program_add_window (HILDON_PROGRAM (app->program), win);
+            g_signal_connect (G_OBJECT (win), "map-event",
+                    GTK_SIGNAL_FUNC (cbViewAreaFullscreenMapped), app);
+            g_signal_connect (G_OBJECT (win), "unmap",
+                    GTK_SIGNAL_FUNC (cbViewAreaFullscreenUnmapped), app);
+            g_signal_connect (G_OBJECT (win), "key-press-event",
+                    GTK_SIGNAL_FUNC (cb_keyPressed), (void *)app);
+        }
+        gtk_widget_show_all (GTK_WIDGET (app->window_fullscreen));
+        app->fullscreen = true;
+    }
+}
+
+void app_normal_screen (Application *app) {
+    if (app->fullscreen) {
+        gtk_widget_hide (GTK_WIDGET (app->window_fullscreen));
+        app->fullscreen = false;
+    }
+}
+
 static void callback_file_open (GtkButton * button, Application * app) {
     gchar *filename = NULL;
     filename = _app_file_chooser(app, GTK_FILE_CHOOSER_ACTION_OPEN);
@@ -134,7 +178,7 @@ static void callback_file_go (GtkButton * button, Application * app) {
     const gchar *val = gtk_combo_box_get_active_text (
                 GTK_COMBO_BOX (app->location_bar));
     if (val && val[0]) {
-        gtk_window_set_title (GTK_WINDOW (app->window), val);
+        gtk_window_set_title (app->window, val);
         openFile (app, val);
         app_insert_location (app, val);
     }
@@ -147,7 +191,7 @@ static void callback_file_save_as (GtkButton * button, Application * app) {
         gchar * info;
         if (saveFile (app->control, filename)) {
             info = g_strdup_printf ("Saved as %s", filename);
-            gtk_window_set_title (GTK_WINDOW (app->window), filename);
+            gtk_window_set_title (app->window, filename);
             app_insert_location (app, filename);
         } else
             info = g_strdup_printf ("Saving as %s failed (%s)", filename, strerror (errno));
@@ -171,7 +215,7 @@ static void callback_file_save (GtkButton * button, Application * app) {
 
 static void callback_file_new (GtkButton * button, Application * app) {
     newFile (app);
-    gtk_window_set_title (GTK_WINDOW (app->window), "");
+    gtk_window_set_title (app->window, "");
 }
 
 static gboolean
@@ -183,6 +227,7 @@ locationbarLostFocus (GtkWidget *gw, GdkEventFocus *gef, Application *app) {
         gtk_widget_show (GTK_WIDGET (gtk_toolbar_get_nth_item (GTK_TOOLBAR (app->main_toolbar), i)));
     app_set_playing (app, app->playing);
     gtk_editable_select_region (GTK_EDITABLE (GTK_BIN (app->location_bar)->child), 0, 0);
+    return false;
 }
 
 static bool first_time_exposed;
@@ -201,7 +246,7 @@ bool cb_window_expose (GtkWidget *w, GdkEventExpose *ev, Application *app) {
 
 static void windowTopMost (GObject * self, GParamSpec *gps, Application * app) {
     (void)gps;
-    if (app->fullscreen && hildon_window_get_is_topmost (app->window))
+    if (app->fullscreen && hildon_window_get_is_topmost (HILDON_WINDOW (app->window)))
         app_normal_screen (app);
 }
 
@@ -287,7 +332,18 @@ static void create_toolbar (Application * app) {
     gtk_widget_show_all (GTK_WIDGET (app->main_toolbar));
     gtk_widget_hide (GTK_WIDGET (app->tb_progress));
     gtk_widget_hide (GTK_WIDGET (app->tb_pause));
-    hildon_window_add_toolbar (app->window, GTK_TOOLBAR(app->main_toolbar));
+    hildon_window_add_toolbar (HILDON_WINDOW (app->window),
+            GTK_TOOLBAR(app->main_toolbar));
+}
+
+static void mainMenuShow (GtkWidget *w, Application *app) {
+    (void)w;
+    app_set_suspend (app, true);
+}
+
+static void mainMenuHide (GtkWidget *w, Application *app) {
+    (void)w;
+    app_set_suspend (app, false);
 }
 
 /* Create the menu items needed for the main view */
@@ -399,7 +455,7 @@ static void create_menu (Application * app) {
         GTK_SIGNAL_FUNC (mainMenuHide), app);
     /* Make all menu widgets visible */
     gtk_widget_show_all (GTK_WIDGET (main_menu));
-    hildon_program_set_common_menu (app->program, main_menu);
+    hildon_program_set_common_menu (HILDON_PROGRAM (app->program), main_menu);
 }
 
 /* Callback for normal D-BUS messages */
@@ -409,7 +465,7 @@ gint dbus_req_handler( const gchar *interface, const gchar *method,
     int i;
 
     if (!strcmp (method, "top_application"))
-        gtk_window_present (GTK_WINDOW (appdata->window));
+        gtk_window_present (appdata->window);
     else if (!strcmp (method, "mime_open") || !strcmp (method, "load_url")) {
         for (i = 0; i < arguments->len; ++i) {
             osso_rpc_t val = g_array_index (arguments, osso_rpc_t, i);
@@ -427,19 +483,10 @@ gint dbus_req_handler( const gchar *interface, const gchar *method,
     return OSSO_OK;
 }
 
-static void setupViewWidget (GtkWidget * w, Application *app) {
-    gtk_widget_add_events (w,
-            GDK_EXPOSURE_MASK | GDK_VISIBILITY_NOTIFY_MASK |
-            GDK_BUTTON_PRESS_MASK | GDK_KEY_PRESS_MASK |
-            GDK_STRUCTURE_MASK);
-    g_signal_connect (G_OBJECT (w), "realize",
-        GTK_SIGNAL_FUNC (cb_view_area_realized), app);
-    g_signal_connect (G_OBJECT (w), "expose-event",
-        GTK_SIGNAL_FUNC (cb_view_area_expose), app);
-    g_signal_connect (G_OBJECT (w), "button-press-event",
-        GTK_SIGNAL_FUNC (cb_view_area_button_press), app);
-    g_signal_connect (G_OBJECT (w), "configure-event",
-            GTK_SIGNAL_FUNC (cb_view_area_configure), app);
+static void programTopMost (GObject *self, GParamSpec *spec, Application *app) {
+    HildonProgram *program = HILDON_PROGRAM (self);
+    (void)spec;
+    app_set_suspend (app, !hildon_program_get_is_topmost (program));
 }
 
 #include <execinfo.h>
@@ -470,6 +517,8 @@ static void sig_abort(int i) {
 
 /* Main application */
 int main (int argc, char* argv[]) {
+    HildonProgram *program;
+    HildonWindow *main_window;
     GtkScrolledWindow *scroll_window;
     PangoContext *pango_cxt;
     PangoFontDescription *pfd;
@@ -491,7 +540,7 @@ int main (int argc, char* argv[]) {
     textdomain(GETTEXT_PACKAGE);
 
     /* Initialize the GTK. */
-    app->osso_context = osso_initialize ("kmplayer", "0.1", FALSE, NULL);
+    app->osso_context = osso_initialize ("com.nokia.kmplayer", "0.8", FALSE, NULL);
     if (!app->osso_context) {
         /*gtk_infoprint (GTK_WINDOW (app->window), "Failed to initialize");*/
         return 1;
@@ -500,10 +549,11 @@ int main (int argc, char* argv[]) {
 
     /* Create the hildon application and setup the title */
 #ifdef BUILD_BORA
-    app->program = HILDON_PROGRAM (hildon_program_new());
+    program = HILDON_PROGRAM (hildon_program_new());
 #else
-    app->program = HILDON_PROGRAM (hildon_program_get_instance());
+    program = HILDON_PROGRAM (hildon_program_get_instance());
 #endif
+    app->program = G_OBJECT (program);
 
     /*app->osso_context = osso_initialize ("kmplayer", "0.1", FALSE, NULL);
     if (!app->osso_context) {
@@ -511,8 +561,8 @@ int main (int argc, char* argv[]) {
         return 1;
     }*/
     /* Create HildonAppView and set it to HildonApp */
-    app->window = HILDON_WINDOW (hildon_window_new ());
-    app->window_fullscreen = HILDON_WINDOW (hildon_window_new ());
+    main_window = HILDON_WINDOW (hildon_window_new ());
+    app->window = GTK_WINDOW (main_window);
 
     /* Add example label to appview */
     app->hsplit_view = GTK_PANED (gtk_hpaned_new ());
@@ -526,20 +576,14 @@ int main (int argc, char* argv[]) {
     gtk_paned_add1 (app->hsplit_view, GTK_WIDGET (scroll_window));
     gtk_paned_add2 (app->hsplit_view, GTK_WIDGET (app->vsplit_view));
     app->view_area = gtk_drawing_area_new ();
-    app->view_area_fullscreen = gtk_drawing_area_new ();
-    setupViewWidget (app->view_area, app);
-    setupViewWidget (app->view_area_fullscreen, app);
-    g_signal_connect (G_OBJECT (app->program), "notify::is-topmost",
+    _app_setup_window (app->view_area, app);
+    g_signal_connect (app->program, "notify::is-topmost",
         GTK_SIGNAL_FUNC (programTopMost), app);
-    g_signal_connect (G_OBJECT (app->window), "destroy",
+    g_signal_connect (G_OBJECT (main_window), "destroy",
         GTK_SIGNAL_FUNC (cb_mainview_deleted), app);
-    g_signal_connect (G_OBJECT (app->window_fullscreen), "map-event",
-        GTK_SIGNAL_FUNC (cbViewAreaFullscreenMapped), app);
-    g_signal_connect (G_OBJECT (app->window_fullscreen), "unmap",
-        GTK_SIGNAL_FUNC (cbViewAreaFullscreenUnmapped), app);
-    g_signal_connect (G_OBJECT (app->window), "expose-event",
+    g_signal_connect (G_OBJECT (main_window), "expose-event",
         GTK_SIGNAL_FUNC (cb_window_expose), app);
-    g_signal_connect (G_OBJECT (app->window), "notify::is-topmost",
+    g_signal_connect (G_OBJECT (main_window), "notify::is-topmost",
         GTK_SIGNAL_FUNC (windowTopMost), app);
     gtk_paned_add1 (app->vsplit_view, app->view_area);
     app->infopanel_view = gtk_text_view_new ();
@@ -569,13 +613,11 @@ int main (int argc, char* argv[]) {
             "resize", TRUE, "shrink", TRUE, 0L);
     g_object_set (G_OBJECT (split_view->child2),
             "resize", TRUE, "shrink", TRUE, 0L);*/
-    gtk_container_add (GTK_CONTAINER (app->window), GTK_WIDGET (app->hsplit_view));
-    gtk_container_add (GTK_CONTAINER (app->window_fullscreen), app->view_area_fullscreen);
+    gtk_container_add (GTK_CONTAINER (main_window), GTK_WIDGET (app->hsplit_view));
     /* Create menu for view */
     create_menu (app);
     create_toolbar (app);
-    hildon_program_add_window (app->program, app->window);
-    hildon_program_add_window (app->program, app->window_fullscreen);
+    hildon_program_add_window (program, main_window);
 
     g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN(app->location_bar))),
             "focus-in-event", GTK_SIGNAL_FUNC (locationbarGainFocus), app);
@@ -585,14 +627,12 @@ int main (int argc, char* argv[]) {
             GTK_SIGNAL_FUNC (locationbarLostFocus), app);
     g_signal_connect (G_OBJECT (app->html_infopanel_view), "focus-in-event",
             GTK_SIGNAL_FUNC (locationbarLostFocus), app);
-    g_signal_connect (G_OBJECT (app->window), "key-press-event",
-            GTK_SIGNAL_FUNC (cb_keyPressed), (void *)app);
-    g_signal_connect (G_OBJECT (app->window_fullscreen), "key-press-event",
+    g_signal_connect (G_OBJECT (main_window), "key-press-event",
             GTK_SIGNAL_FUNC (cb_keyPressed), (void *)app);
     /* Begin the main application */
     gtk_paned_set_position (app->hsplit_view, HSPLIT);
     gtk_paned_set_position (app->vsplit_view, 200);
-    gtk_widget_show_all (GTK_WIDGET (app->window));
+    gtk_widget_show_all (GTK_WIDGET (main_window));
 
     osso_mime_set_cb (app->osso_context, cb_openUrls, app);
     if (osso_rpc_set_cb_f (app->osso_context,
@@ -601,7 +641,7 @@ int main (int argc, char* argv[]) {
                 "com.nokia.kmplayer",
                 dbus_req_handler, app) !=
             OSSO_OK) {
-        hildon_banner_show_information (GTK_WINDOW (app->window),
+        hildon_banner_show_information (GTK_WIDGET (app->window),
                 NULL, "Failed to set dbus_req_handler");
     }
     app_init_control (app);
