@@ -42,17 +42,13 @@
 extern "C" {
 #endif
 
-#ifndef __HILDON_PROGRAM_H__
-typedef struct _HildonProgram HildonProgram;
-typedef struct _HildonWindow HildonWindow;
-#endif
 /*typedef struct _GConfClient GConfClient;*/
 
 /* Application UI data struct */
 typedef struct _Application {
-    HildonProgram *program;
-    HildonWindow *window;
-    HildonWindow *window_fullscreen;
+    GObject *program;
+    GtkWindow *window;
+    GtkWindow *window_fullscreen;
     osso_context_t *osso_context;
     GtkWidget * main_toolbar;
     GtkToolItem * tb_play;
@@ -97,9 +93,6 @@ void togglePlaylistShow (GtkCheckMenuItem *checkmenuitem, Application * app);
 void togglePlaylistShowAll (GtkCheckMenuItem *checkmenuitem, Application * app);
 void togglePlaylistEdit (GtkCheckMenuItem *checkmenuitem, Application * app);
 void toggleMediaServer (GtkCheckMenuItem *radio, Application * app);
-void mainMenuShow (GtkWidget *, Application * app);
-void mainMenuHide (GtkWidget *, Application * app);
-void programTopMost (GObject * self, GParamSpec * param, Application * app);
 void cb_mainview_deleted (GtkObject * w, Application * app);
 gboolean cb_keyPressed (GtkWidget *, GdkEventKey * e, Application *app);
 void cb_row_activated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *arg2, Application * app);
@@ -132,6 +125,8 @@ void app_init_control (Application *app) MAEMO_NO_EXPORT;
 void app_insert_location (Application *app, const char *loc) MAEMO_NO_EXPORT;
 void app_open_location (const char *filename, Application *app) MAEMO_NO_EXPORT;
 void app_normal_screen (Application *app) MAEMO_NO_EXPORT;
+void app_full_screen (Application *app) MAEMO_NO_EXPORT;
+void app_set_suspend (Application *app, bool suspend) MAEMO_NO_EXPORT;
 void app_set_info_content (Application *app, const char * utf8, bool plaintext) MAEMO_NO_EXPORT;
 void app_set_playing (Application *app, bool) MAEMO_NO_EXPORT;
 void app_set_title (const char *title, Application *app) MAEMO_NO_EXPORT;
