@@ -290,7 +290,8 @@ public:
     virtual void updateDimensions ();
     virtual Surface *surface ();
 
-    NodePtrW rootLayout;
+    NodePtrW root_layout;
+    NodePtrW default_region;
 };
 
 /**
