@@ -12,13 +12,11 @@ extern "C" {
 #include <gtkhtml/gtkhtml.h>
 }
 #ifdef BUILD_BORA
-#include <hildon-widgets/hildon-program.h>
-#include <hildon-widgets/gtk-infoprint.h>
-#include <hildon-widgets/hildon-seekbar.h>
+# include <hildon-widgets/gtk-infoprint.h>
+# include <hildon-widgets/hildon-seekbar.h>
 #else
-#include <hildon/hildon-program.h>
-#include <hildon/hildon-banner.h>
-#include <hildon/hildon-seekbar.h>
+# include <hildon/hildon-banner.h>
+# include <hildon/hildon-seekbar.h>
 #endif
 //#include <gdk/gdk.h>
 //#include <pango/pango-font.h>
@@ -281,7 +279,7 @@ void Control::playCurrent () {
         playlist_data->current->activate ();
         updateViewAreaSizes ();
     } else {
-        NodePtr mrl = back_request
+        Mrl *mrl = back_request
             ? back_request->mrl ()->linkNode ()
             : playlist_data->current->mrl ()->linkNode ();
         //debugLog () << "playCurrent " << m_process->playing () << " " << mrl->mrl ()->resolved << endl;
@@ -293,11 +291,11 @@ void Control::playCurrent () {
                 return; // FIXME
         }
         back_request = 0L;
-        if (!mrl->mrl ()->src.isEmpty () && mrl->mrl ()->resolved) {
+        if (!mrl->src.isEmpty () && mrl->resolved) {
             updateViewAreaSizes ();
             if (m_process->hasXv ())
                 XSync (GDK_DISPLAY_XDISPLAY (gtk_widget_get_display (VIEWAREA(m_app)->viewWidget ())), false);
-            m_process->play (mrl->mrl ()->linkNode ());
+            m_process->play (mrl);
         } else
             errorLog() << "playCurrent and mrl not resolved" << endl;
     }
@@ -361,7 +359,7 @@ bool Control::resolveURL (NodePtr m) {
     debugLog() << "resolveURL " << url << " mime:" << mimestr << endl;
     if (mimestr.isEmpty ()) {
         for (NodePtr p = mrl->parentNode (); p; p = p->parentNode ()) {
-            Mrl * m = p->mrl ();
+            Mrl *m = p->mrl ();
             if (m && m->linkNode ()->audio_only) {
                 mrl->linkNode ()->audio_only = true;
                 break;
@@ -449,11 +447,15 @@ void Control::jobResult (Job * job) {
     else
         m_resolve_info = rinfo->next;
     if (rinfo->resolving_mrl) {
+        Mrl *mrl = rinfo->resolving_mrl->mrl ();
         if (!rinfo->data.isEmpty ())
-            readPlaylist (rinfo->resolving_mrl, rinfo->data);
+            readPlaylist (mrl, rinfo->data);
     //debugLog () << "set resolved " << rinfo->resolving_mrl->mrl ()->src << endl;
-        rinfo->resolving_mrl->mrl ()->resolved = true;
-        rinfo->resolving_mrl->undefer ();
+        mrl->resolved = true;
+        if (mrl->mimetype.isEmpty ())
+            mrl->mimetype = job->contentType ();
+        mrl->audio_only = isAudioOnlyMime (mrl->mimetype);
+        mrl->undefer ();
     }
 }
 
@@ -624,7 +626,7 @@ bool Control::docTimerEvent () {
 }
 
 bool Control::setCurrent (NodePtr n) {
-    debugLog () << "setCurrent " << (n ? n->nodeName () : "-") << endl;
+    debugLog() << "setCurrent " << (n && n->mrl() ? n->mrl()->src : "-")<< endl;
     if (playlist_data->current == n)
         return true;
     playlist_data->current = n;
@@ -671,7 +673,7 @@ void Control::stateElementChanged (Node* n, Node::State os, Node::State ns) {
         stop ();
         app_set_playing (m_app, false);
     } else if ((ns == Node::state_deactivated || ns == Node::state_finished) &&
-            n->mrl () && process ()->mrl ().ptr () == n->mrl()->linkNode ()) {
+            n->mrl () && process ()->mrl () == n->mrl()->linkNode ()) {
         process ()->stop ();
         updateViewAreaSizes (); // move away video widget
     } else if ((ns == Node::state_deferred ||
@@ -697,9 +699,9 @@ void Control::stateElementChanged (Node* n, Node::State os, Node::State ns) {
                 setCurrent (n);
         }
     }
-    //if (n->expose () &&
-    //        (ns == Node::state_activated || ns == Node::state_deactivated))
-    //    updatePlaylistView ();
+    if (n == playlist_data->current &&
+            (ns == Node::state_activated || ns == Node::state_deactivated))
+        updatePlaylistView ();
 }
 
 void Control::updateViewAreaSizes () {
@@ -801,15 +803,17 @@ void Control::stateChanged (Process * p, Process::State os, Process::State ns) {
     } else if (ns == Process::Paused &&
             playlist_data->document->state != Node::state_deferred &&
             !playlist_data->document->document ()->postponed ()) {
-        if (gtk_window_has_toplevel_focus (GTK_WINDOW (m_app->window_fullscreen)) ||
-                gtk_window_has_toplevel_focus (GTK_WINDOW (m_app->window)))
+        if ((m_app->window_fullscreen &&
+                gtk_window_has_toplevel_focus (GTK_WINDOW (m_app->window_fullscreen))) ||
+                gtk_window_has_toplevel_focus (m_app->window))
             m_process->pause ();
         else
             playlist_data->document->defer ();
     } else if (ns == Process::Playing) {
+        p->mrl ()->audio_only |= !p->hasVideo ();
         if (p->mrl ()->state == Element::state_deferred) {
             AudioVideoMedia *media =
-                static_cast <AudioVideoMedia *> (p->mrl()->mrl()->media_object);
+                static_cast <AudioVideoMedia *> (p->mrl()->media_object);
             if (media)
                 media->ignore_pause = true;
             p->mrl ()->undefer ();
@@ -868,6 +872,7 @@ void Control::stateChanged (Process * p, Process::State os, Process::State ns) {
             }
             updateTree (m_app, m_app->recents_tree_id);
         }
+        updatePlayTree (m_app);
     }
 }
 
@@ -975,24 +980,6 @@ void KMPlayer::jump (Node *n, Control *ctr) {
         ctr->updatePlaylistView ();
 }
 
-static void _app_full_screen (Application *app) {
-    if (!CONTROL(app)->playlist_data->document ||
-            !CONTROL(app)->playlist_data->document->active ()) {
-        return;
-    }
-    if (!app->fullscreen) {
-        gtk_widget_show_all (GTK_WIDGET (app->window_fullscreen));
-        app->fullscreen = true;
-    }
-}
-
-void app_normal_screen (Application *app) {
-    if (app->fullscreen) {
-        gtk_widget_hide (GTK_WIDGET (app->window_fullscreen));
-        app->fullscreen = false;
-    }
-}
-
 void app_set_info_content (Application *app, const char *utf8, bool plaintext) {
     if (!plaintext && utf8[0]) {
         gtk_widget_hide (app->info_viewport);
@@ -1085,11 +1072,13 @@ gboolean cb_keyPressed (GtkWidget *, GdkEventKey * e, Application *app) {
         case GDK_F6: //HILDON_HARDKEY_FULLSCREEN:
             //if (app->control->process ()->playing ()) {
              //   int w, h;
-            if (!app->fullscreen)
-                _app_full_screen (app);
-            else
+            if (!app->fullscreen) {
+                if (CONTROL(app)->playlist_data->document &&
+                        CONTROL(app)->playlist_data->document->active ())
+                    app_full_screen (app);
+            } else {
                 app_normal_screen (app);
-            //}
+            }
             break;
         case GDK_F7: //HILDON_HARDKEY_INCREASE
             if (CONTROL(app)->process ()->playing ())
@@ -1144,12 +1133,12 @@ void toggleMediaServer (GtkCheckMenuItem *radio, Application *app) {
         CONTROL(app)->m_config->writeEntry(GCONF_KEY_PLAYER, String(p->name()));
 }
 
-static void setSuspendState (Application *a, bool suspend) {
+void app_set_suspend (Application *a, bool suspend) {
     PlayListData *pd = CONTROL(a)->playlist_data;
     if (pd->document &&
             pd->document->active () &&
             (!CONTROL(a)->process ()->playing () ||
-             CONTROL(a)->process()->mrl()->mrl()->view_mode ==Mrl::WindowMode ||
+             CONTROL(a)->process()->mrl()->view_mode ==Mrl::WindowMode ||
              CONTROL(a)->process ()->hasVideo ())) {
         if (pd->document->state == Node::state_deferred) {
             if (!suspend)
@@ -1159,18 +1148,6 @@ static void setSuspendState (Application *a, bool suspend) {
     }
 }
 
-void mainMenuShow (GtkWidget *, Application * app) {
-    setSuspendState (app, true);
-}
-
-void mainMenuHide (GtkWidget *, Application * app) {
-    setSuspendState (app, false);
-}
-
-void programTopMost (GObject * self, GParamSpec *, Application * app) {
-    HildonProgram *program = HILDON_PROGRAM (self);
-    setSuspendState (app, !hildon_program_get_is_topmost (program));
-}
 static bool locationbar_initialized;
 
 gboolean
