@@ -42,31 +42,31 @@ using namespace KMPlayer;
 
 //-----------------------------------------------------------------------------
 
-namespace KMPlayer {
-    Node * fromXMLDocumentTag (NodePtr & d, const String & tag) {
-        const char * const name = (const char *) tag;
-        if (!strcmp (name, "smil"))
-            return new SMIL::Smil (d);
-        else if (!strcasecmp (name, "asx"))
-            return new ASX::Asx (d);
-        else if (!strcasecmp (name, "imfl"))
-            return new RP::Imfl (d);
-        else if (!strcasecmp (name, "rss"))
-            return new RSS::Rss (d);
-        else if (!strcasecmp (name, "feed"))
-            return new ATOM::Feed (d);
-        else if (!strcasecmp (name, "playlist"))
-            return new XSPF::Playlist (d);
-        else if (!strcasecmp (name, "url"))
-            return new GenericURL (d, String ());
-        else if (!strcasecmp (name, "mrl") ||
-                !strcasecmp (name, "document"))
-            return new GenericMrl (d);
-        return 0L;
-    }
+Node * KMPlayer::fromXMLDocumentTag (NodePtr & d, const String & tag) {
+    const char * const name = (const char *) tag;
+    if (!strcmp (name, "smil"))
+        return new SMIL::Smil (d);
+    else if (!strcasecmp (name, "asx"))
+        return new ASX::Asx (d);
+    else if (!strcasecmp (name, "imfl"))
+        return new RP::Imfl (d);
+    else if (!strcasecmp (name, "rss"))
+        return new RSS::Rss (d);
+    else if (!strcasecmp (name, "feed"))
+        return new ATOM::Feed (d);
+    else if (!strcasecmp (name, "playlist"))
+        return new XSPF::Playlist (d);
+    else if (!strcasecmp (name, "url"))
+        return new GenericURL (d, String ());
+    else if (!strcasecmp (name, "mrl") ||
+            !strcasecmp (name, "document"))
+        return new GenericMrl (d);
+    return 0L;
+}
 
 //-----------------------------------------------------------------------------
 
+namespace {
     struct XMLStringlet {
         const String str;
         XMLStringlet (const String & s) : str (s) {}
@@ -838,9 +838,7 @@ Postpone::~Postpone () {
 
 //-----------------------------------------------------------------------------
 
-namespace {
-    static NodePtr dummy_element;
-}
+static NodePtr dummy_element;
 
 Document::Document (const String & s, PlayListNotify * n)
  : Mrl (dummy_element, id_node_document),
@@ -908,12 +906,8 @@ void Document::defer () {
 }
 
 void Document::undefer () {
-    if (!postpone_lock) {
-        Mrl::undefer ();
-    } else {
-        setState (state_activated);
-        postpone_lock = 0L;
-    }
+    postpone_lock = 0L;
+    Mrl::undefer ();
 }
 
 void Document::reset () {
@@ -1347,10 +1341,8 @@ static void cdataEnd (void *data) {
     builder->cdataEnd ();
 }
 
-namespace KMPlayer {
-
 KMPLAYER_EXPORT
-void readXML (NodePtr root, TextStream & in, const String & firstline, bool set_opener) {
+void KMPlayer::readXML (NodePtr root, TextStream & in, const String & firstline, bool set_opener) {
     bool ok = true;
     DocumentBuilder builder (root, set_opener);
     XML_Parser parser = XML_ParserCreate (0L);
@@ -1376,8 +1368,6 @@ void readXML (NodePtr root, TextStream & in, const String & firstline, bool set_
     //return ok;
 }
 
-} // namespace KMPlayer
-
 //-----------------------------------------------------------------------------
 #else // HAVE_EXPAT
 
